#CloudyDayStart.py
import pygame
import os
import sys

from pygame.locals import *


from engine.Gameworld import Gameworld
from common.Utility import *

from HeroCloud import HeroCloud


class CloudyDayStart(Gameworld):
    """
        Intro screen for the game.
        Display instructions and a single cloud floating across the screen.
    """

    def __init__(self):
        """
            Load fonts and sounds.
            Start playing background noise.
        """
        self.showHelp = False
        self.titleFont = getFont("kberry", 50)
        self.otherFont = getFont("kberry", 25)
        self.hc = HeroCloud(pygame.Rect(50, 250, 200, 50))
        self.windSpeed = 2.3
        self.ambience = pygame.mixer.Sound(load_sound("ambience.ogg"))
	self.ambience.play(loops=-1)

    def tick(self, time):
        """
            Update the logic for the start screen.
        """
        self.hc.setWind(self.windSpeed, 0)
        self.hc.update(time)

    def draw(self, surface):
        """
            Draw instructions and the hero cloud.
        """
        pygame.draw.rect(surface, [46, 118, 222], pygame.Rect(0, 0, XRES, YRES))
	pygame.draw.line(surface, [0, 100, 0], [0, YRES - 4], [XRES, YRES - 4], 10)
	self.hc.draw(surface)
	pygame.draw.aaline(surface, [50, 50, 50, 128], [self.hc.lowestX + self.hc.trueX - 50, YRES - 8], [self.hc.highestX + self.hc.trueX - 50, YRES - 8])


	surf = self.titleFont.render("A CLOUDY DAY", True, (255, 255, 255, 128))
        surface.blit(surf, (XRES / 2 - 150, 10, 100, 20))

        surf = self.otherFont.render("a game by james reinebold", True, (255, 255, 255, 128))
        surface.blit(surf, (400, 100, 100, 20))

        surf = self.otherFont.render("press space to play", True, (255, 255, 255, 128))
        surface.blit(surf, (400, 120, 100, 20))


        if self.showHelp == False:
            surf = self.otherFont.render("press enter to view control help", True, (255, 255, 255, 128))
            surface.blit(surf, (400, 140, 100, 20))
        else:
            surf = self.otherFont.render("press enter to hide control help", True, (255, 255, 255, 128))
            surface.blit(surf, (400, 140, 100, 20))

        if self.showHelp:
            surf = self.otherFont.render("left       blow left", True, (255, 255, 255, 128))
            surface.blit(surf, (200, 180, 100, 20))

            surf = self.otherFont.render("right      blow right", True, (255, 255, 255, 128))
            surface.blit(surf, (200, 200, 100, 20))

            surf = self.otherFont.render("space     rain", True, (255, 255, 255, 128))
            surface.blit(surf, (200, 220, 100, 20))

            surf = self.otherFont.render("enter      thunder", True, (255, 255, 255, 128))
            surface.blit(surf, (200, 240, 100, 20))

            surf = self.otherFont.render("escape    clear current garden and return to this screen", True, (255, 255, 255, 128))
            surface.blit(surf, (200, 260, 100, 20))
        

    def fadeInHelp(self):
        """
            Start showing the key help.
        """
        self.showHelp = True

    def fadeOutHelp(self):
        """
            Stop showing the key help.
        """
        self.showHelp = False

    def handleEvent(self, event):
        """
            Handle user key input.
        """
        #handle exit program
        if event.type == pygame.QUIT:
            sys.exit()
        elif event.type == KEYDOWN:
            if event.key == K_SPACE:
                #go to game
                self.controller.getScene(1).reset()
                self.controller.getScene(1).hero = self.hc
                self.controller.changeScene(1)
            elif event.key == K_RETURN:
                #show help screen
                if self.showHelp == False:
                    self.fadeInHelp()
                else:
                    self.fadeOutHelp()
        
