#engine.AtlanSpriteGroup.py

from pygame.locals import *
from pygame.sprite import Group


class AtlanSpriteGroup(Group):
	"""
	A wrapper for the pygame class SpriteGroup.
	"""

	def __init__(self):
		"""
		Constructs a new AtlanSpriteGroup object.
		"""
		Group.__init__(self)
		
	def handleEvent(self, event):
		"""
			Pass on "event" to all of the sprites in this group
		"""
		for thing in self.sprites():
			thing.handleEvent(event)
			
	def draw(self, screen):
		"""
			Draw all of the sprites in this group to "screen."
		"""
		sprites = self.sprites()
		for sprite in sprites:
			sprite.draw(screen)
			
	def update(self, delta):
		"""
			Updates all of the sprites in this group to know that time "delta" has elapsed since the last call to update(delta).
		"""
		sprites = self.sprites()
		for sprite in sprites:
			sprite.update(delta)
			
	def findAtlanSprite(self, idnum):
		"""
			Return the AtlanSprite with "idnum" as its identifier.
			Returns None if it cannot be found.
		"""
		sprites = self.sprites()
		for sprite in sprites:
			if sprite.id == idnum:
				return sprite
		return None